@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2019 The git2r contributors
+ *  Copyright (C) 2013-2020 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,6 +16,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
@@ -29,10 +30,15 @@
  * Init slots in S3 class git_reference.
  *
  * @param source A git_reference pointer
+ * @param repo S3 class git_repository that contains the reference
  * @param dest S3 class git_reference to initialize
  * @return void
  */
-static void git2r_reference_init(git_reference *source, SEXP dest)
+static void
+git2r_reference_init(
+    git_reference *source,
+    SEXP repo,
+    SEXP dest)
 {
     char sha[GIT_OID_HEXSZ + 1];
 
@@ -81,6 +87,8 @@ static void git2r_reference_init(git_reference *source, SEXP dest)
             git2r_S3_item__git_reference__target,
             Rf_ScalarString(NA_STRING));
     }
+
+    SET_VECTOR_ELT(dest, git2r_S3_item__git_reference__repo, Rf_duplicate(repo));
 }
 
 /**
@@ -90,7 +98,10 @@ static void git2r_reference_init(git_reference *source, SEXP dest)
  * @param shorthand The short name for the reference
  * @return S3 class git_reference object
  */
-SEXP git2r_reference_dwim(SEXP repo, SEXP shorthand)
+SEXP attribute_hidden
+git2r_reference_dwim(
+    SEXP repo,
+    SEXP shorthand)
 {
     int error, nprotect = 0;
     SEXP result = R_NilValue;
@@ -115,7 +126,7 @@ SEXP git2r_reference_dwim(SEXP repo, SEXP shorthand)
     nprotect++;
     Rf_setAttrib(result, R_ClassSymbol,
                  Rf_mkString(git2r_S3_class__git_reference));
-    git2r_reference_init(reference, result);
+    git2r_reference_init(reference, repo, result);
 
 cleanup:
     git_reference_free(reference);
@@ -136,7 +147,9 @@ cleanup:
  * @param repo S3 class git_repository
  * @return VECXSP with S3 objects of class git_reference
  */
-SEXP git2r_reference_list(SEXP repo)
+SEXP attribute_hidden
+git2r_reference_list(
+    SEXP repo)
 {
     int error, nprotect = 0;
     size_t i;
@@ -174,7 +187,7 @@ SEXP git2r_reference_list(SEXP repo)
             reference = Rf_mkNamed(VECSXP, git2r_S3_items__git_reference));
         Rf_setAttrib(reference, R_ClassSymbol,
                      Rf_mkString(git2r_S3_class__git_reference));
-        git2r_reference_init(ref, reference);
+        git2r_reference_init(ref, repo, reference);
         SET_STRING_ELT(names, i, Rf_mkChar(ref_list.strings[i]));
 
         git_reference_free(ref);
